@@ -40,8 +40,9 @@ void DisplayHeader(void)
 
 void usage(void)
 {
-    printf("email:\tjnelson@crl.com\n");
-    printf("WWW:\thttp://www.crl.com/~jnelson/htp/\n\n");
+    printf("Original author, Jim Nelson.   Current maintainer Robert King\n");
+    printf("email:\trobert.king@mailbox.gu.edu.au\n");
+    printf("WWW:\thttp://www.ens.gu.edu.au/robertk/htp/\n\n");
     printf("usage: %s [options] <source HTML file> <reformatted HTML file>\n",
         PROGRAM_NAME);
     printf("       %s [options] @<response file>\n", PROGRAM_NAME);
